package
module
Version:
v0.0.0-...-76180e5
Opens a new window with list of versions in this module.
Published: Aug 6, 2025
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type BuildSpec struct {
Name string `yaml:"name"`
Version string `yaml:"version"`
Build []struct {
Path string `yaml:"path"`
Dockerfile string `yaml:"dockerfile"`
Tag string `yaml:"tag"`
} `yaml:"build"`
Output []struct {
Type string `yaml:"type"`
Name string `yaml:"name"`
} `yaml:"output"`
}
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.